Learn R Programming

specklestar (version 0.0.1.7)

speckle_stat: Statistics of speckles

Description

Calculate statistics of speckles in the series of 512 x 512 speckle images and filter "bad" frames

Usage

speckle_stat(filename, threshold = 50000L)

Arguments

filename

a character string with the path name to a file.

threshold

an integer (default is 50000).

Value

The list with 2 elements 'badFrames' and 'hist': 1 number of bad frames, 2 double vector of speckle statistics.

Examples

Run this code
# NOT RUN {
obj_filename <- system.file("extdata", "ads15182_550_2_frames.dat", package = "specklestar")
spec_stat <- speckle_stat(obj_filename)
# }

Run the code above in your browser using DataLab