powered by
Calculate statistics of speckles in the series of 512 x 512 speckle images and filter "bad" frames
speckle_stat(filename, threshold = 50000L)
a character string with the path name to a file.
an integer (default is 50000).
The list with 2 elements 'badFrames' and 'hist': 1 number of bad frames, 2 double vector of speckle statistics.
# NOT RUN { obj_filename <- system.file("extdata", "ads15182_550_2_frames.dat", package = "specklestar") spec_stat <- speckle_stat(obj_filename) # }
Run the code above in your browser using DataLab